#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-workspace-model.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-workspace-model.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-workspace-model.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__workspace_model_t {
    QByteArrayData data[12];
    char stringdata0[169];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__workspace_model_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__workspace_model_t qt_meta_stringdata_octave__workspace_model = {
    {
QT_MOC_LITERAL(0, 0, 23), // "octave::workspace_model"
QT_MOC_LITERAL(1, 24, 13), // "model_changed"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 22), // "prompt_variable_editor"
QT_MOC_LITERAL(4, 62, 13), // "set_workspace"
QT_MOC_LITERAL(5, 76, 9), // "top_level"
QT_MOC_LITERAL(6, 86, 5), // "debug"
QT_MOC_LITERAL(7, 92, 16), // "symbol_info_list"
QT_MOC_LITERAL(8, 109, 7), // "syminfo"
QT_MOC_LITERAL(9, 117, 15), // "clear_workspace"
QT_MOC_LITERAL(10, 133, 15), // "notice_settings"
QT_MOC_LITERAL(11, 149, 19) // "const gui_settings*"

    },
    "octave::workspace_model\0model_changed\0"
    "\0prompt_variable_editor\0set_workspace\0"
    "top_level\0debug\0symbol_info_list\0"
    "syminfo\0clear_workspace\0notice_settings\0"
    "const gui_settings*"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__workspace_model[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,
       3,    0,   40,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    3,   41,    2, 0x0a /* Public */,
       9,    0,   48,    2, 0x0a /* Public */,
      10,    1,   49,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool, QMetaType::Bool, 0x80000000 | 7,    5,    6,    8,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 11,    2,

       0        // eod
};

void octave::workspace_model::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        workspace_model *_t = static_cast<workspace_model *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->model_changed(); break;
        case 1: _t->prompt_variable_editor(); break;
        case 2: _t->set_workspace((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const symbol_info_list(*)>(_a[3]))); break;
        case 3: _t->clear_workspace(); break;
        case 4: _t->notice_settings((*reinterpret_cast< const gui_settings*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (workspace_model::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&workspace_model::model_changed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (workspace_model::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&workspace_model::prompt_variable_editor)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject octave::workspace_model::staticMetaObject = {
    { &QAbstractTableModel::staticMetaObject, qt_meta_stringdata_octave__workspace_model.data,
      qt_meta_data_octave__workspace_model,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::workspace_model::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::workspace_model::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__workspace_model.stringdata0))
        return static_cast<void*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int octave::workspace_model::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void octave::workspace_model::model_changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void octave::workspace_model::prompt_variable_editor()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
